@@ -113,6 +113,14 @@ public:
 	 */
 	static unsigned count(LinkedObject *root);
 
+	/**
+	 * Get member by index.
+	 * @return indexed member in linked list.
+	 * @param root pionter to list we are indexing.
+	 * @param index member to find.
+	 */
+	static LinkedObject *getIndexed(LinkedObject *root, unsigned index);
+
 	/**
 	 * Get next effective object when iterating.
 	 * @return next linked object in list.
@@ -217,6 +225,14 @@ public:
 	 */
 	LinkedObject *get(void);
 
+	/**
+	 * Get an indexed member from the ordered index.
+	 * @param index of member to fetch.
+	 * @return LinkedObject member of index.
+	 */
+	inline LinkedObject *getIndexed(unsigned index) const
+		{return LinkedObject::getIndexed((LinkedObject*)head, index);};
+
 	/**
 	 * Return first object in list for iterators.
 	 * @return first object in list.
@@ -567,6 +583,14 @@ public:
 	inline NamedTree *getParent(void) const
 		{return parent;};
 
+	/**
+	 * Get child by index number.
+	 * @param index of child to fetch.
+	 * @return indexed child node.
+	 */
+	inline NamedTree *getIndexed(unsigned index) const
+		{return static_cast<NamedTree *>(child.getIndexed(index));};
+
 	/**
 	 * Get the ordered index of our child nodes.
 	 * @return ordered index of our children.
@@ -614,6 +638,25 @@ public:
 	 */
 	inline bool isRoot(void) const
 		{return (parent == NULL);};
+
+	/**
+	 * Add leaf to a trunk, by order.  If NULL, just remove.
+	 * @param trunk we add leaf node to.
+	 */
+	void relistTail(NamedTree *trunk);
+
+	/**
+	 * Add leaf to a trunk, by reverse order.  If NULL, just remove.
+	 * @param trunk we add leaf node to.
+	 */
+	void relistHead(NamedTree *trunk);
+
+	/**
+	 * Default relist is by tail...
+	 * @param trunk we add leaf node to, NULL to delist.
+	 */
+	inline void relist(NamedTree *trunk = NULL)
+		{relistTail(trunk);};
 };
 
 /**
@@ -1283,6 +1326,14 @@ public:
 	inline void operator=(const T& data)
 		{value = data;};
 
+	/**
+	 * Get child member node by index.
+	 * @param index of child member.
+	 * @return node or NULL if past end.
+	 */
+	inline treemap *getIndexed(unsigned index) const
+		{return static_cast<treemap*>(child.getIndexed(index));};
+
 	/**
 	 * Get the typed parent node for our node.
 	 * @return parent node or NULL if root of tree.
