@@ -40,7 +40,9 @@ static size_t cpr_pagesize(void)
 #endif
 }
 
-mempager::mempager(size_t ps)
+
+
+memalloc::memalloc(size_t ps)
 {
 #ifdef	HAVE_SYSCONF
 	size_t paging = sysconf(_SC_PAGESIZE);
@@ -51,9 +53,6 @@ mempager::mempager(size_t ps)
 #else
 	size_t paging = 1024;
 #endif
-
-	pthread_mutex_init(&mutex, NULL);
-
 	if(!ps)
 		ps = paging;
 	else if(ps > paging)
@@ -82,13 +81,12 @@ mempager::mempager(size_t ps)
 	page = NULL;
 }
 
-mempager::~mempager()
+memalloc::~memalloc()
 {
-	mempager::purge();
-	pthread_mutex_destroy(&mutex);
+	memalloc::purge();
 }
 
-unsigned mempager::utilization(void)
+unsigned memalloc::utilization(void)
 {
 	unsigned long used = 0, alloc = 0;
 	page_t *mp = page;
@@ -107,20 +105,18 @@ unsigned mempager::utilization(void)
 	return used;
 }
 
-void mempager::purge(void)
+void memalloc::purge(void)
 {
 	page_t *next;
-	pthread_mutex_lock(&mutex);	
 	while(page) {
 		next = page->next;
 		free(page);
 		page = next;
 	}
-	pthread_mutex_unlock(&mutex);
 	count = 0;
 }
 
-mempager::page_t *mempager::pager(void)
+memalloc::page_t *memalloc::pager(void)
 {
 	page_t *npage = NULL;
 #ifdef	HAVE_POSIX_MEMALIGN
@@ -152,11 +148,7 @@ use:
 	return npage;
 }
 
-void mempager::dealloc(void *mem)
-{
-}
-
-void *mempager::alloc_locked(size_t size)
+void *memalloc::alloc(size_t size)
 {
 	assert(size > 0);
 
@@ -181,19 +173,66 @@ void *mempager::alloc_locked(size_t size)
 	return mem;
 }
 
+char *memalloc::dup(const char *str)
+{
+    if(!str)
+        return NULL;
+	size_t len = strlen(str) + 1;
+    char *mem = static_cast<char *>(alloc(len));
+    String::set(mem, len, str);
+    return mem;
+}
+
+void *memalloc::dup(void *obj, size_t size)
+{
+	assert(obj != NULL);
+	assert(size > 0);
+
+    char *mem = static_cast<char *>(alloc(size));
+	memcpy(mem, obj, size);
+    return mem;
+}
+
+mempager::mempager(size_t ps) :
+memalloc(ps)
+{
+	pthread_mutex_init(&mutex, NULL);
+}
+
+mempager::~mempager()
+{
+	memalloc::purge();
+	pthread_mutex_destroy(&mutex);
+}
+
+unsigned mempager::utilization(void)
+{
+	unsigned long used;
+
+	pthread_mutex_lock(&mutex);
+	used = memalloc::utilization();
+	pthread_mutex_unlock(&mutex);
+	return used;
+}
+
+void mempager::purge(void)
+{
+	pthread_mutex_lock(&mutex);	
+	memalloc::purge();
+	pthread_mutex_unlock(&mutex);
+}
+
+void mempager::dealloc(void *mem)
+{
+}
+
 void *mempager::alloc(size_t size)
 {
 	assert(size > 0);
 
 	void *mem;
-
-	crit(size <= (pagesize - sizeof(page_t)), "mempager page size exceeded");
-
-	while(size % sizeof(void *))
-		++size;
-
 	pthread_mutex_lock(&mutex);
-	mem = alloc_locked(size);
+	mem = memalloc::alloc(size);
 	pthread_mutex_unlock(&mutex);
 	return mem;
 }
@@ -208,26 +247,6 @@ char *mempager::dup(const char *str)
 	return mem;
 }
 
-char *mempager::dup_locked(const char *str)
-{
-    if(!str)
-        return NULL;
-	size_t len = strlen(str) + 1;
-    char *mem = static_cast<char *>(alloc_locked(len));
-    String::set(mem, len, str);
-    return mem;
-}
-
-char *mempager::dup_locked(void *obj, size_t size)
-{
-	assert(obj != NULL);
-	assert(size > 0);
-
-    char *mem = static_cast<char *>(alloc_locked(size));
-	memcpy(mem, obj, size);
-    return mem;
-}
-
 void *mempager::dup(void *obj, size_t size)
 {
 	assert(obj != NULL);
@@ -437,7 +456,7 @@ bool keyassoc::create(char *id, void *data)
 		ptr = (caddr_t)obj;
 	}
 	if(ptr == NULL)
-		ptr = (caddr_t)alloc_locked(sizeof(keydata) + size * 8);
+		ptr = (caddr_t)memalloc::alloc(sizeof(keydata) + size * 8);
 	kd = new(ptr) keydata(this, id, paths, 8 + size * 8);					
 	kd->data = data;
 	++count;
@@ -468,7 +487,7 @@ bool keyassoc::assign(char *id, void *data)
 			ptr = (caddr_t)obj;
 		}
 		if(ptr == NULL)
-			ptr = (caddr_t)alloc_locked(sizeof(keydata) + size * 8);
+			ptr = (caddr_t)memalloc::alloc(sizeof(keydata) + size * 8);
 		kd = new(ptr) keydata(this, id, paths, 8 + size * 8);				
 		++count;	
 	}
